==> ejc-assistrmat-api-3.0.0-20220915.064758-213-sources.jar: com/ejianc/business/outrmat/delivery/vo/OutRmatDeliveryDetailVO.java <==
package com.ejianc.business.outrmat.delivery.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * out-出库单子表
 * 
 * @author generator
 * 
 */
public class OutRmatDeliveryDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long deliveryId; // 发货主键ID
    private Long sourceId; // 来源主键ID
    private Long sourceDetailId; // 来源明细主键ID
    private Long materialId; // 物资主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String calculateUnitName; // 计量单位名称
    private Long calculateUnitId; // 计量单位主键
    private Long rentUnitId; // 计租单位主键
    private String rentUnitName; // 计租单位主键
    private String spec; // 规格型号
    private BigDecimal calculateNum; // 计量数量
    private BigDecimal rentNum; // 计租数量
    private BigDecimal useNum; // 库存可用数量
    private BigDecimal theoryWeight; // 理论重量
    private BigDecimal roughWeight; // 毛重
    private BigDecimal tareWeight; // 皮重
    private BigDecimal netWeight; // 净重
    private BigDecimal standardOffsetRate; // 标准偏差率
    private BigDecimal actualOffsetRate; // 实际偏差率
    private Integer requireDetailFlag; // 是否符合要求 0-否，1-是
    private Date rentDetailDate; // 计租日期
    private Integer rentType; // 计租方式
    private String memo; // 备注
    private Integer rentCalculationType; // 计租方式：0-日租，1-月租，2-工程量租
    @TableField(value = "trans_scale")
    private BigDecimal transScale; // 转换系数

    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }

    public Integer getRentCalculationType() {
        return rentCalculationType;
    }

    public void setRentCalculationType(Integer rentCalculationType) {
        this.rentCalculationType = rentCalculationType;
    }

    public Long getDeliveryId() {
        return deliveryId;
    }

    public void setDeliveryId(Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getCalculateUnitName() {
        return calculateUnitName;
    }

    public void setCalculateUnitName(String calculateUnitName) {
        this.calculateUnitName = calculateUnitName;
    }
    public Long getCalculateUnitId() {
        return calculateUnitId;
    }

    public void setCalculateUnitId(Long calculateUnitId) {
        this.calculateUnitId = calculateUnitId;
    }
    public Long getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(Long rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getCalculateNum() {
        return calculateNum;
    }

    public void setCalculateNum(BigDecimal calculateNum) {
        this.calculateNum = calculateNum;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getUseNum() {
        return useNum;
    }

    public void setUseNum(BigDecimal useNum) {
        this.useNum = useNum;
    }
    public BigDecimal getTheoryWeight() {
        return theoryWeight;
    }

    public void setTheoryWeight(BigDecimal theoryWeight) {
        this.theoryWeight = theoryWeight;
    }
    public BigDecimal getRoughWeight() {
        return roughWeight;
    }

    public void setRoughWeight(BigDecimal roughWeight) {
        this.roughWeight = roughWeight;
    }
    public BigDecimal getTareWeight() {
        return tareWeight;
    }

    public void setTareWeight(BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }
    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }
    public BigDecimal getStandardOffsetRate() {
        return standardOffsetRate;
    }

    public void setStandardOffsetRate(BigDecimal standardOffsetRate) {
        this.standardOffsetRate = standardOffsetRate;
    }
    public BigDecimal getActualOffsetRate() {
        return actualOffsetRate;
    }

    public void setActualOffsetRate(BigDecimal actualOffsetRate) {
        this.actualOffsetRate = actualOffsetRate;
    }
    public Integer getRequireDetailFlag() {
        return requireDetailFlag;
    }

    public void setRequireDetailFlag(Integer requireDetailFlag) {
        this.requireDetailFlag = requireDetailFlag;
    }
    public Date getRentDetailDate() {
        return rentDetailDate;
    }

    public void setRentDetailDate(Date rentDetailDate) {
        this.rentDetailDate = rentDetailDate;
    }
    public Integer getRentType() {
        return rentType;
    }

    public void setRentType(Integer rentType) {
        this.rentType = rentType;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-assistrmat-api-3.0.0-20221101.020733-293-sources.jar: com/ejianc/business/outrmat/delivery/vo/OutRmatDeliveryDetailVO.java <==
package com.ejianc.business.outrmat.delivery.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * out-出库单子表
 * 
 * @author generator
 * 
 */
public class OutRmatDeliveryDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long deliveryId; // 发货主键ID
    private Long sourceId; // 来源主键ID
    private Long sourceDetailId; // 来源明细主键ID
    private Long materialId; // 物资主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String calculateUnitName; // 计量单位名称
    private Long calculateUnitId; // 计量单位主键
    private Long rentUnitId; // 计租单位主键
    private String rentUnitName; // 计租单位主键
    private String spec; // 规格型号
    private BigDecimal calculateNum; // 计量数量
    private BigDecimal rentNum; // 计租数量
    private BigDecimal useNum; // 库存可用数量
    private BigDecimal theoryWeight; // 理论重量
    private BigDecimal roughWeight; // 毛重
    private BigDecimal tareWeight; // 皮重
    private BigDecimal netWeight; // 净重
    private BigDecimal standardOffsetRate; // 标准偏差率
    private BigDecimal actualOffsetRate; // 实际偏差率
    private Integer requireDetailFlag; // 是否符合要求 0-否，1-是
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date rentDetailDate; // 计租日期
    private Integer rentType; // 计租方式
    private String memo; // 备注
    private Integer rentCalculationType; // 计租方式：0-日租，1-月租，2-工程量租
    @TableField(value = "trans_scale")
    private BigDecimal transScale; // 转换系数

    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }

    public Integer getRentCalculationType() {
        return rentCalculationType;
    }

    public void setRentCalculationType(Integer rentCalculationType) {
        this.rentCalculationType = rentCalculationType;
    }

    public Long getDeliveryId() {
        return deliveryId;
    }

    public void setDeliveryId(Long deliveryId) {
        this.deliveryId = deliveryId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getCalculateUnitName() {
        return calculateUnitName;
    }

    public void setCalculateUnitName(String calculateUnitName) {
        this.calculateUnitName = calculateUnitName;
    }
    public Long getCalculateUnitId() {
        return calculateUnitId;
    }

    public void setCalculateUnitId(Long calculateUnitId) {
        this.calculateUnitId = calculateUnitId;
    }
    public Long getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(Long rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getCalculateNum() {
        return calculateNum;
    }

    public void setCalculateNum(BigDecimal calculateNum) {
        this.calculateNum = calculateNum;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getUseNum() {
        return useNum;
    }

    public void setUseNum(BigDecimal useNum) {
        this.useNum = useNum;
    }
    public BigDecimal getTheoryWeight() {
        return theoryWeight;
    }

    public void setTheoryWeight(BigDecimal theoryWeight) {
        this.theoryWeight = theoryWeight;
    }
    public BigDecimal getRoughWeight() {
        return roughWeight;
    }

    public void setRoughWeight(BigDecimal roughWeight) {
        this.roughWeight = roughWeight;
    }
    public BigDecimal getTareWeight() {
        return tareWeight;
    }

    public void setTareWeight(BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }
    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }
    public BigDecimal getStandardOffsetRate() {
        return standardOffsetRate;
    }

    public void setStandardOffsetRate(BigDecimal standardOffsetRate) {
        this.standardOffsetRate = standardOffsetRate;
    }
    public BigDecimal getActualOffsetRate() {
        return actualOffsetRate;
    }

    public void setActualOffsetRate(BigDecimal actualOffsetRate) {
        this.actualOffsetRate = actualOffsetRate;
    }
    public Integer getRequireDetailFlag() {
        return requireDetailFlag;
    }

    public void setRequireDetailFlag(Integer requireDetailFlag) {
        this.requireDetailFlag = requireDetailFlag;
    }
    public Date getRentDetailDate() {
        return rentDetailDate;
    }

    public void setRentDetailDate(Date rentDetailDate) {
        this.rentDetailDate = rentDetailDate;
    }
    public Integer getRentType() {
        return rentType;
    }

    public void setRentType(Integer rentType) {
        this.rentType = rentType;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
